package com.sun.xml.internal.ws.api.server;

import java.util.Iterator;
import java.util.HashSet;
import java.util.Set;

public enum LazyMOMProvider
{
    INSTANCE;
    
    private final Set<LazyMOMProvider.WSEndpointScopeChangeListener> endpointsWaitingForMOM;
    private final Set<LazyMOMProvider.DefaultScopeChangeListener> listeners;
    private volatile LazyMOMProvider.Scope scope;
    
    private LazyMOMProvider() {
        this.endpointsWaitingForMOM = new HashSet();
        this.listeners = new HashSet();
        this.scope = LazyMOMProvider.Scope.STANDALONE;
    }
    
    public void initMOMForScope(LazyMOMProvider.Scope scope) {
        if (this.scope == LazyMOMProvider.Scope.GLASSFISH_JMX || (scope == LazyMOMProvider.Scope.STANDALONE && (this.scope == LazyMOMProvider.Scope.GLASSFISH_JMX || this.scope == LazyMOMProvider.Scope.GLASSFISH_NO_JMX)) || this.scope == scope) {
            return;
        }
        this.scope = scope;
        this.fireScopeChanged();
        return;
    }
    
    private void fireScopeChanged() {
        for (LazyMOMProvider.ScopeChangeListener wsEndpoint : this.endpointsWaitingForMOM) {
            wsEndpoint.scopeChanged(this.scope);
        }
        for (LazyMOMProvider.ScopeChangeListener listener : this.listeners) {
            listener.scopeChanged(this.scope);
        }
    }
    
    public void registerListener(LazyMOMProvider.DefaultScopeChangeListener listener) {
        this.listeners.add(listener);
        if (!this.isProviderInDefaultScope()) {
            listener.scopeChanged(this.scope);
        }
    }
    
    private boolean isProviderInDefaultScope() {
        return this.scope == LazyMOMProvider.Scope.STANDALONE;
    }
    
    public LazyMOMProvider.Scope getScope() {
        return this.scope;
    }
    
    public void registerEndpoint(LazyMOMProvider.WSEndpointScopeChangeListener wsEndpoint) {
        this.endpointsWaitingForMOM.add(wsEndpoint);
        if (!this.isProviderInDefaultScope()) {
            wsEndpoint.scopeChanged(this.scope);
        }
    }
    
    public void unregisterEndpoint(LazyMOMProvider.WSEndpointScopeChangeListener wsEndpoint) {
        this.endpointsWaitingForMOM.remove(wsEndpoint);
    }
    
    public enum Scope
    {
        STANDALONE, 
        GLASSFISH_NO_JMX, 
        GLASSFISH_JMX;
    }
    
    public interface DefaultScopeChangeListener extends LazyMOMProvider.ScopeChangeListener
    {
    }
    
    public interface ScopeChangeListener
    {
        public abstract void scopeChanged(LazyMOMProvider.Scope p0);
    }
    
    public interface WSEndpointScopeChangeListener extends LazyMOMProvider.ScopeChangeListener
    {
    }
}
